@@ -1495,7 +1495,7 @@ class Population:
         )
         code_string += (
             indent * (depth + 1)
-            + "print('with a total probability of {}'.format(self.grid_options['probtot']))\n"
+            + "print('with a total probability of {}'.format(self.grid_options['_probtot']))\n"
         )
 
         if dry_run:
